MAVENN
------

MAVENN is a Python package for inferring quantitative models of sequence-function
relationships from multiplexed assays of variant effects. 
MAVENN currently implements global epistasis regression and noise agnostic regression.
Please see 'https://mavenn.readthedocs.io' 
for additional details.